// ResetServerWhenEmpty.cpp : Defines the entry point for the DLL application.
//

#include <string>
#include "bzfsAPI.h"

BZ_GET_PLUGIN_VERSION

class ResetServerWhenEmpty : public bz_EventHandler
{
public:
        virtual void process (bz_EventData *eventData);

	bool isEnabled;
	bool noTimer;
};

ResetServerWhenEmpty	RSWE;

class RSWECommand : public bz_CustomSlashCommandHandler
{
public:
	virtual ~RSWECommand(){};
	virtual bool handle ( int playerID, bzApiString command, bzApiString message, bzAPIStringList *params );
};

RSWECommand	RSWE_Command;



BZF_PLUGIN_CALL int bz_Load ( const char* commandLine )
{
	RSWE.noTimer = (commandLine == "noTimer");
	if (!RSWE.noTimer)
	{
		bz_registerEvent(bz_eTickEvent, &RSWE);
		bz_setMaxWaitTime(bz_getBZDBDouble("_rejoinTime"));
	}
	else
		bz_registerEvent(bz_ePlayerPartEvent, &RSWE);
	bz_registerCustomSlashCommand("rswe", &RSWE_Command);
	bz_debugMessage(4,"ResetServerWhenEmpty plugin loaded");
	return 0;
}

BZF_PLUGIN_CALL int bz_Unload ( void )
{
	if (!RSWE.noTimer)
		bz_removeEvent(bz_eTickEvent, &RSWE);
	else
		bz_removeEvent(bz_ePlayerPartEvent, &RSWE);
	bz_removeCustomSlashCommand("rswe");
	bz_debugMessage(4,"ResetServerWhenEmpty plugin unloaded");
	return 0;
}

void ResetServerWhenEmpty::process(bz_EventData *eventData)
{
	int totaltanks =
		bz_getTeamCount(eRogueTeam) +
		bz_getTeamCount(eRedTeam) +
		bz_getTeamCount(eGreenTeam) +
		bz_getTeamCount(eBlueTeam) +
		bz_getTeamCount(ePurpleTeam) +
		bz_getTeamCount(eRabbitTeam);
	if (totaltanks == 0)
	{
		if (isEnabled)
		{
			bz_sendTextMessage(BZ_SERVER, BZ_ALLUSERS, "RSWE is enabled. The server will now restart.");
			bz_shutdown();
		}
	}
}

bool RSWECommand::handle(int playerID, bzApiString command, bzApiString message, bzAPIStringList *params)
{
	bz_PlayerRecord *pr = bz_getPlayerByIndex(playerID);
	std::string cs = pr->callsign.c_str();
	bz_freePlayerRecord(pr);
	if (message == "status")
	{
		if (!bz_hasPerm(playerID, "RSWESTATUS"))
		{
			bz_sendTextMessage(BZ_SERVER, playerID, (cs + ", you do not have permission to use the /rswe status command.").c_str());
		}
		else
		{
			if (RSWE.isEnabled)
			{
				bz_sendTextMessage(BZ_SERVER, playerID, "RSWE is currently activated.");
			}
			else
			{
				bz_sendTextMessage(BZ_SERVER, playerID, "RSWE is currently deactivated.");
			}
		}
	}
	else
	{
		if (!bz_hasPerm(playerID, "RSWE"))
		{
			bz_sendTextMessage(BZ_SERVER, playerID, (cs + ", you do not have permission to use the /rswe command.").c_str());
		}
		else
		{
			if (message == "on")
			{
				RSWE.isEnabled = true;
				bz_sendTextMessage(BZ_SERVER, playerID, "RSWE enabled.");
				bz_sendTextMessage(BZ_SERVER, BZ_ALLUSERS, (cs + " has enabled RSWE.").c_str());
			}
			else if (message == "off")
			{
				RSWE.isEnabled = false;
				bz_sendTextMessage(BZ_SERVER, playerID, "RSWE disabled.");
				bz_sendTextMessage(BZ_SERVER, BZ_ALLUSERS, (cs + " has disabled RSWE.").c_str());
			}
			else if (message == "toggle")
			{
				if (RSWE.isEnabled)
				{
					RSWE.isEnabled = false;
					bz_sendTextMessage(BZ_SERVER, playerID, "RSWE disabled.");
					bz_sendTextMessage(BZ_SERVER, BZ_ALLUSERS, (cs + " has disabled RSWE.").c_str());
				}
				else
				{
					RSWE.isEnabled = true;
					bz_sendTextMessage(BZ_SERVER, playerID, "RSWE enabled.");
					bz_sendTextMessage(BZ_SERVER, BZ_ALLUSERS, (cs + " has enabled RSWE.").c_str());
				}
			}
			else
			{
				bz_sendTextMessage(BZ_SERVER, playerID, "/rswe on|off|toggle|status");
			}
		}
	}
	return true;
}

// Local Variables: ***
// mode:C++ ***
// tab-width: 8 ***
// c-basic-offset: 2 ***
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8


